import unittest

from lpreports.launchpad.milestone import Milestone


class MilestoneTestCases(unittest.TestCase):
    def test_milestone_comparing(self):
        fixtures = (
            # major versions
            (('10', '9'), ('9', '10'), ('10', '10')),
            # major+minor versions
            (('10.10.8', '10.8.10'), ('10.8.10', '10.10.8'), ('10.10.8', '10.10.8')),
            # major+minor with different length
            (('10.4', '10.3.6'), ('10.3.6', '10.4'), ('10.4', '10.4')),
            # major+minor+suffix versions
            (('4.1-update', '4.1-mu'), ('4.1-mu', '4.1-update'), ('4.1-mu', '4.1-mu')),
            # major+minor vs major+minor+suffix
            (('10.3.4', '10.3-mu'), ('10.3-mu', '10.3.4'), ('10.3-mu', '10.3-mu')),
            # 'next' must have the most biggest weight
            (('next', '4.1-update'), ('10.10.8', 'next'), ('next', 'next')),
        )

        # Comparison of two instances of Milestone
        for f in fixtures:
            self.assertGreater(Milestone(f[0][0]), Milestone(f[0][1]))
            self.assertLess(Milestone(f[1][0]), Milestone(f[1][1]))
            self.assertEqual(Milestone(f[2][0]), Milestone(f[2][1]))

        # Comparison of Milestone object and string
        for f in fixtures:
            self.assertGreater(Milestone(f[0][0]), f[0][1])
            self.assertLess(Milestone(f[1][0]), f[1][1])
            self.assertEqual(Milestone(f[2][0]), f[2][1])

            self.assertGreater(f[0][0], Milestone(f[0][1]))
            self.assertLess(f[1][0], Milestone(f[1][1]))
            self.assertEqual(f[2][0], Milestone(f[2][1]))

        # Compare Milestone object and None
        self.assertGreater(Milestone('4.1-update'), None)
